efmlrs package
==============

Subpackages
-----------

.. toctree::

   efmlrs.postprocessing
   efmlrs.preprocessing
   efmlrs.util

Submodules
----------

efmlrs.post module
------------------

.. automodule:: efmlrs.post
   :members:
   :undoc-members:
   :show-inheritance:

efmlrs.pre module
-----------------

.. automodule:: efmlrs.pre
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: efmlrs
   :members:
   :undoc-members:
   :show-inheritance:
